Learn R Programming

RRphylo (version 2.5.9)

rescaleRR: Rescaling phylogenetic trees according to RRphylo rates

Description

The function rescales all branches and leaves of the phylogenetic tree according to branch-wise phenotypic evolutionary rates fitted by RRphylo.

Usage

rescaleRR(tree,RR)

Arguments

tree

the phylogenetic tree to be rescaled.

RR

the result of RRphylo performed on tree. When a multivariate phenotype is used, rescaling is operated on the norm-2 vector of rates

Value

Rescaled phylogenetic tree.

References

Castiglione, S., Serio, C., Piccolo, M., Mondanaro, A., Melchionna, M., Di Febbraro, M., Sansalone, G., Wroe, S., & Raia, P. (2020). The influence of domestication, insularity and sociality on the tempo and mode of brain size evolution in mammals. Biological Journal of the Linnean Society,in press. doi:10.1093/biolinnean/blaa186

Examples

Run this code
# NOT RUN {
library(ape)

rtree(100)->tree
fastBM(tree)->y

RRphylo::RRphylo(tree,y)->RR
rescaleRR(tree,RR)->treeRes
# }

Run the code above in your browser using DataLab